==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xt2ppmHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablePPM摜t@C쐬"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-H*/
#define HOLT "(X)W"
#define HOLC "(X)W"
#define HOLF NULL

/*-V*/
#define VERT "(Y)W"
#define VERC "(Y)W"
#define VERF NULL

/*-c*/
#define RGBT "Red,Green,Blue̍ږ"
#define RGBC "Red,Green,Blue̍ږ"
#define RGBF NULL

/*-M*/
#define MAXT "ő̐Fl"
#define MAXC "ő̐Fl"

/*-S*/
#define SIZT "TCY(X,Y)"
#define SIZC "TCY(X,Y)"

/*-n*/
#define NULT "NULLl(Red,Green,Blue)l"
#define NULC "NULLl(Red,Green,Blue)l"

/*-i*/
#define INFT "PPMt@C"
#define INFC "ȗ͕W͂ǂݍ"

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "XMLtablẽf[^PPMt@C쐬B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  xt2ppm -H XW -V YW -c ,, -n 255,255,255 -i image.xt -o image.ppm\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "ppm2xt,xtregionseg"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/ja-sjis/xt2ppmHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTablePPM摜t@C쐬"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-H*/
#define HOLT "(X)W"
#define HOLC "(X)W"
#define HOLF NULL

/*-V*/
#define VERT "(Y)W"
#define VERC "(Y)W"
#define VERF NULL

/*-c*/
#define RGBT "Red,Green,Blue̍ږ"
#define RGBC "Red,Green,Blue̍ږ"
#define RGBF NULL

/*-M*/
#define MAXT "ő̐Fl"
#define MAXC "ő̐Fl"

/*-S*/
#define SIZT "TCY(X,Y)"
#define SIZC "TCY(X,Y)"

/*-n*/
#define NULT "NULLl(Red,Green,Blue)l"
#define NULC "NULLl(Red,Green,Blue)l"

/*-i*/
#define INFT "PPMt@C"
#define INFC "ȗ͕W͂ǂݍ"

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "XMLtablẽf[^PPMt@C쐬B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  xt2ppm -H XW -V YW -c ,, -n 255,255,255 -i image.xt -o image.ppm\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "ppm2xt,xtregionseg"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
